==> spring-web-2.5.0-sources.jar: cn/ipokerface/web/controller/BaseController.java <==
package cn.ipokerface.web.controller;

import cn.ipokerface.common.http.Header;
import cn.ipokerface.common.utils.FileUtils;
import cn.ipokerface.common.utils.StringUtils;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.nio.charset.Charset;

/**
 * Created by       PokerFace
 * Create Date      2019-11-23.
 * Email:           <a href="mailto:214888341@163.com">214888341@163.com</a>
 * Version          1.0.0
 * <p>
 * Description:     some api to operate request and response
 *                  All controller should extend this {@link BaseController}
 */


public abstract class BaseController {


    /**
     *  Get client real ip address .
     *  Header of client ip is {@link Header#X_FORWARDED_FOR_HEADER}
     *  and this header may rewrite by gateway service such as <code>nignx</code>
     *
     * @param request tomcat request
     * @return real ip address of client
     */
    protected String getClientIpAddress(HttpServletRequest request){

        String forwardedFor = request.getHeader(Header.X_FORWARDED_FOR_HEADER);

        if (StringUtils.isEmpty(forwardedFor)) return request.getRemoteAddr();


        String[] addresses = forwardedFor.split(",");

        if (addresses != null && addresses.length > 0) return addresses[0];

        return forwardedFor;
    }


    /**
     *  write file to response
     *
     * @param response httpResponse
     * @param filePath file path of file
     * @throws IOException exception io
     */
    protected void writeFile(HttpServletResponse response, String filePath) throws IOException {
        File file = new File(filePath);

        if (file == null || !file.exists()) return;
        writeFile(response, new FileInputStream(file), file.getName());

    }


    /**
     *  Write file of inputStream to outputStream
     *
     * @param response httpResponse
     * @param inputStream inputStream
     * @param filename file name just name
     * @throws IOException exception io
     */
    protected void writeFile(HttpServletResponse response, InputStream inputStream, String filename) throws IOException{
        String outFile = new String(filename.getBytes(), Charset.forName("ISO8859-1"));

        response.setContentType(Header.CONTENT_TYPE_STREAM);
        response.setHeader(Header.CONTENT_DISPOSITION, "attachment;filename="+ outFile);
        response.addHeader(Header.CACHE_CONTROL, "no-cache");

        FileUtils.writeTo(inputStream, response.getOutputStream());
    }
}

==> spring-web-2.7.1-sources.jar: cn/ipokerface/web/controller/BaseController.java <==
package cn.ipokerface.web.controller;

import cn.ipokerface.common.http.Header;
import cn.ipokerface.common.logback.LoggerAdapter;
import cn.ipokerface.common.utils.FileUtils;
import cn.ipokerface.common.utils.StringUtils;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URLEncoder;

/**
 * Created by       PokerFace
 * Create Date      2019-11-23.
 * Email:           <a href="mailto:214888341@163.com">214888341@163.com</a>
 * Version          1.0.0
 * <p>
 * Description:     some api to operate request and response
 *                  All controller should extend this {@link BaseController}
 */


public abstract class BaseController extends LoggerAdapter {


    /**
     *  Get client real ip address .
     *  Header of client ip is {@link Header#X_FORWARDED_FOR_HEADER}
     *  and this header may rewrite by gateway service such as <code>nignx</code>
     *
     * @param request tomcat request
     * @return real ip address of client
     */
    protected String getClientIpAddress(HttpServletRequest request){

        String forwardedFor = request.getHeader(Header.X_FORWARDED_FOR_HEADER);

        if (StringUtils.isEmpty(forwardedFor)) return request.getRemoteAddr();


        String[] addresses = forwardedFor.split(",");

        if (addresses != null && addresses.length > 0) return addresses[0];

        return forwardedFor;
    }


    /**
     *  write file to response
     *
     * @param response httpResponse
     * @param filePath file path of file
     * @throws IOException exception io
     */
    protected void writeFile(HttpServletResponse response, String filePath) throws IOException {
        File file = new File(filePath);

        if (file == null || !file.exists()) return;
        writeFile(response, new FileInputStream(file), file.getName());

    }


    /**
     *  Write file of inputStream to outputStream
     *
     * @param response httpResponse
     * @param inputStream inputStream
     * @param filename file name just name
     * @throws IOException exception io
     */
    protected void writeFile(HttpServletResponse response, InputStream inputStream, String filename) throws IOException{
        String outFile = URLEncoder.encode(filename, "UTF-8");

        response.setCharacterEncoding("UTF-8");
        response.setHeader(Header.CONTENT_TYPE, "application/vnd.ms-excel");
        response.setHeader(Header.CONTENT_DISPOSITION, "attachment;filename="+ outFile);
        response.addHeader(Header.CACHE_CONTROL, "no-cache");

        FileUtils.writeTo(inputStream, response.getOutputStream());
    }
}
